*********************************************
For developers: AST Nodes and Transformations
*********************************************


AST Nodes
=========

.. automodule:: pystencils.astnodes
   :members:



Transformations
===============


.. automodule:: pystencils.transformations
   :members:
